@@ -4,6 +4,6 @@ import { simpleGet, simplePost, simplePut } from '@tamanu/shared/utils/crudHelpe
 
 export const diagnosis = express.Router();
 
-diagnosis.get('/:id', simpleGet('EncounterDiagnosis'));
+diagnosis.get('/:id', simpleGet('EncounterDiagnosis', { auditAccess: true }));
 diagnosis.put('/:id', simplePut('EncounterDiagnosis'));
 diagnosis.post('/$', simplePost('EncounterDiagnosis'));
